@@ -1,13 +1,13 @@
 # Copyrights 2009-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 use warnings;
 use strict;
 
 package XML::Compile::SOAP12::Operation;
 use vars '$VERSION';
-$VERSION = '3.03';
+$VERSION = '3.04';
 
 use base 'XML::Compile::SOAP::Operation';
 
@@ -259,7 +259,7 @@ sub compileClient(@)
       , kind         => $kind
       , encode       => $client->_sender(@so, %args)
       , decode       => $client->_receiver(@ro, %args)
-      , transport    => $self->compileTransporter(%args)
+      , transport    => $self->compileTransporter(%args, soap => 'SOAP12')
       , async        => $args{async}
       , soap         => $args{soap}
       );
